@@ -1,16 +1,13 @@
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
  * Copyright by The HDF Group.                                               *
- * Copyright by the Board of Trustees of the University of Illinois.         *
  * All rights reserved.                                                      *
  *                                                                           *
  * This file is part of HDF5.  The full HDF5 copyright notice, including     *
  * terms governing use, modification, and redistribution, is contained in    *
- * the files COPYING and Copyright.html.  COPYING can be found at the root   *
- * of the source code distribution tree; Copyright.html can be found at the  *
- * root level of an installed copy of the electronic HDF5 document set and   *
- * is linked from the top-level documents page.  It can also be found at     *
- * http://hdfgroup.org/HDF5/doc/Copyright.html.  If you do not have          *
- * access to either file, you may request a copy from help@hdfgroup.org.     *
+ * the COPYING file, which can be found at the root of the source code       *
+ * distribution tree, or in https://www.hdfgroup.org/licenses.               *
+ * If you do not have access to either file, you may request a copy from     *
+ * help@hdfgroup.org.                                                        *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
 
 /*
@@ -22,83 +19,52 @@
 /* Module Setup */
 /****************/
 
-#define H5T_PACKAGE		/*suppress error about including H5Tpkg	  */
-
-/* Interface initialization */
-#define H5_INTERFACE_INIT_FUNC	H5T_init_compound_interface
-
+#include "H5Tmodule.h" /* This source code file is part of the H5T module */
 
 /***********/
 /* Headers */
 /***********/
-#include "H5private.h"		/*generic functions			  */
-#include "H5Eprivate.h"		/*error handling			  */
-#include "H5Iprivate.h"		/*ID functions		   		  */
-#include "H5MMprivate.h"	/*memory management			  */
-#include "H5Tpkg.h"		/*data-type functions			  */
+#include "H5private.h"   /*generic functions			  */
+#include "H5Eprivate.h"  /*error handling			  */
+#include "H5Iprivate.h"  /*ID functions		   		  */
+#include "H5MMprivate.h" /*memory management			  */
+#include "H5Tpkg.h"      /*data-type functions			  */
 
 /****************/
 /* Local Macros */
 /****************/
 
-
 /******************/
 /* Local Typedefs */
 /******************/
 
-
 /********************/
 /* Package Typedefs */
 /********************/
 
-
 /********************/
 /* Local Prototypes */
 /********************/
-static herr_t H5T_pack(const H5T_t *dt);
-
+static herr_t H5T__pack(const H5T_t *dt);
+static htri_t H5T__is_packed(const H5T_t *dt);
+static H5T_t *H5T__reopen_member_type(const H5T_t *dt, unsigned membno);
 
 /*********************/
 /* Public Variables */
 /*********************/
 
-
 /*********************/
 /* Package Variables */
 /*********************/
 
-
 /*****************************/
 /* Library Private Variables */
 /*****************************/
 
-
 /*******************/
 /* Local Variables */
 /*******************/
 
-
-
-/*--------------------------------------------------------------------------
-NAME
-   H5T_init_compound_interface -- Initialize interface-specific information
-USAGE
-    herr_t H5T_init_compound_interface()
-RETURNS
-    Non-negative on success/Negative on failure
-DESCRIPTION
-    Initializes any interface-specific data or routines.  (Just calls
-    H5T_init() currently).
---------------------------------------------------------------------------*/
-static herr_t
-H5T_init_compound_interface(void)
-{
-    FUNC_ENTER_NOAPI_NOINIT_NOERR
-
-    FUNC_LEAVE_NOAPI(H5T_init())
-} /* H5T_init_compound_interface() */
-
-
 /*-------------------------------------------------------------------------
  * Function:	H5Tget_member_offset
  *
@@ -112,27 +78,22 @@ H5T_init_compound_interface(void)
  *				H5Tget_member_dims() fails with the same
  *				arguments.
  *
- * Programmer:	Robb Matzke
- *		Wednesday, January  7, 1998
- *
- * Modifications:
- *
  *-------------------------------------------------------------------------
  */
 size_t
 H5Tget_member_offset(hid_t type_id, unsigned membno)
 {
-    H5T_t	*dt;            /* Datatype to query */
-    size_t	ret_value;      /* Return value */
+    H5T_t *dt;        /* Datatype to query */
+    size_t ret_value; /* Return value */
 
     FUNC_ENTER_API(0)
     H5TRACE2("z", "iIu", type_id, membno);
 
     /* Check args */
-    if(NULL == (dt = (H5T_t *)H5I_object_verify(type_id, H5I_DATATYPE)) || H5T_COMPOUND != dt->shared->type)
-	HGOTO_ERROR(H5E_ARGS, H5E_BADTYPE, 0, "not a compound datatype")
-    if(membno >= dt->shared->u.compnd.nmembs)
-	HGOTO_ERROR(H5E_ARGS, H5E_BADVALUE, 0, "invalid member number")
+    if (NULL == (dt = (H5T_t *)H5I_object_verify(type_id, H5I_DATATYPE)) || H5T_COMPOUND != dt->shared->type)
+        HGOTO_ERROR(H5E_ARGS, H5E_BADTYPE, 0, "not a compound datatype");
+    if (membno >= dt->shared->u.compnd.nmembs)
+        HGOTO_ERROR(H5E_ARGS, H5E_BADVALUE, 0, "invalid member number");
 
     /* Value */
     ret_value = H5T_GET_MEMBER_OFFSET(dt->shared, membno);
@@ -141,7 +102,6 @@ done:
     FUNC_LEAVE_API(ret_value)
 } /* end H5Tget_member_offset() */
 
-
 /*-------------------------------------------------------------------------
  * Function:	H5T_get_member_offset
  *
@@ -156,9 +116,6 @@ done:
  *				H5Tget_member_dims() fails with the same
  *				arguments.
  *
- * Programmer:	Raymond Lu
- *		October 8, 2002
- *
  *-------------------------------------------------------------------------
  */
 size_t
@@ -166,13 +123,12 @@ H5T_get_member_offset(const H5T_t *dt, unsigned membno)
 {
     FUNC_ENTER_NOAPI_NOINIT_NOERR
 
-    HDassert(dt);
-    HDassert(membno < dt->shared->u.compnd.nmembs);
+    assert(dt);
+    assert(membno < dt->shared->u.compnd.nmembs);
 
     FUNC_LEAVE_NOAPI(dt->shared->u.compnd.memb[membno].offset)
 } /* end H5T_get_member_offset() */
 
-
 /*-------------------------------------------------------------------------
  * Function:	H5Tget_member_class
  *
@@ -182,38 +138,32 @@ H5T_get_member_offset(const H5T_t *dt, unsigned membno)
  *
  *		Failure: H5T_NO_CLASS
  *
- * Programmer:	Quincey Koziol
- *		Thursday, November  9, 2000
- *
- * Modifications:
- *
  *-------------------------------------------------------------------------
  */
 H5T_class_t
 H5Tget_member_class(hid_t type_id, unsigned membno)
 {
-    H5T_t	*dt;            /* Datatype to query */
-    H5T_class_t	ret_value;      /* Return value */
+    H5T_t      *dt;        /* Datatype to query */
+    H5T_class_t ret_value; /* Return value */
 
     FUNC_ENTER_API(H5T_NO_CLASS)
     H5TRACE2("Tt", "iIu", type_id, membno);
 
     /* Check args */
-    if(NULL == (dt = (H5T_t *)H5I_object_verify(type_id, H5I_DATATYPE)) || H5T_COMPOUND != dt->shared->type)
-        HGOTO_ERROR(H5E_ARGS, H5E_BADTYPE, H5T_NO_CLASS, "not a compound datatype")
-    if(membno >= dt->shared->u.compnd.nmembs)
-        HGOTO_ERROR(H5E_ARGS, H5E_BADVALUE, H5T_NO_CLASS, "invalid member number")
+    if (NULL == (dt = (H5T_t *)H5I_object_verify(type_id, H5I_DATATYPE)) || H5T_COMPOUND != dt->shared->type)
+        HGOTO_ERROR(H5E_ARGS, H5E_BADTYPE, H5T_NO_CLASS, "not a compound datatype");
+    if (membno >= dt->shared->u.compnd.nmembs)
+        HGOTO_ERROR(H5E_ARGS, H5E_BADVALUE, H5T_NO_CLASS, "invalid member number");
 
     /* Get the type's class.  We have to use this function to get type class
      *  because of the concern of variable-length string.
      */
-    ret_value = H5T_GET_CLASS(dt->shared->u.compnd.memb[membno].type->shared, FALSE);
+    ret_value = H5T_GET_CLASS(dt->shared->u.compnd.memb[membno].type->shared, false);
 
 done:
     FUNC_LEAVE_API(ret_value)
 } /* end H5Tget_member_class() */
 
-
 /*-------------------------------------------------------------------------
  * Function:	H5Tget_member_type
  *
@@ -225,47 +175,46 @@ done:
  *				modifying the returned datatype does not
  *				modify the member type.
  *
- *		Failure:	Negative
- *
- * Programmer:	Robb Matzke
- *		Wednesday, January  7, 1998
+ *		Failure:	H5I_INVALID_HID
  *
  *-------------------------------------------------------------------------
  */
 hid_t
 H5Tget_member_type(hid_t type_id, unsigned membno)
 {
-    H5T_t	*dt;                    /* Datatype to query */
-    H5T_t	*memb_dt = NULL;        /* Member datatype */
-    hid_t	ret_value;              /* Return value */
+    H5T_t *dt;             /* Datatype to query */
+    H5T_t *memb_dt = NULL; /* Member datatype */
+    hid_t  ret_value;      /* Return value */
 
-    FUNC_ENTER_API(FAIL)
+    FUNC_ENTER_API(H5I_INVALID_HID)
     H5TRACE2("i", "iIu", type_id, membno);
 
     /* Check args */
-    if(NULL == (dt = (H5T_t *)H5I_object_verify(type_id, H5I_DATATYPE)) || H5T_COMPOUND != dt->shared->type)
-	HGOTO_ERROR(H5E_ARGS, H5E_BADTYPE, FAIL, "not a compound datatype")
-    if(membno >= dt->shared->u.compnd.nmembs)
-	HGOTO_ERROR(H5E_ARGS, H5E_BADVALUE, FAIL, "invalid member number")
-    if(NULL == (memb_dt = H5T_get_member_type(dt, membno, H5T_COPY_REOPEN)))
-	HGOTO_ERROR(H5E_DATATYPE, H5E_CANTINIT, FAIL, "unable to retrieve member type")
-    if((ret_value = H5I_register(H5I_DATATYPE, memb_dt, TRUE)) < 0)
-	HGOTO_ERROR(H5E_DATATYPE, H5E_CANTREGISTER, FAIL, "unable register datatype atom")
+    if (NULL == (dt = (H5T_t *)H5I_object_verify(type_id, H5I_DATATYPE)) || H5T_COMPOUND != dt->shared->type)
+        HGOTO_ERROR(H5E_ARGS, H5E_BADTYPE, H5I_INVALID_HID, "not a compound datatype");
+    if (membno >= dt->shared->u.compnd.nmembs)
+        HGOTO_ERROR(H5E_ARGS, H5E_BADVALUE, H5I_INVALID_HID, "invalid member number");
+
+    /* Retrieve the datatype for the member */
+    if (NULL == (memb_dt = H5T__reopen_member_type(dt, membno)))
+        HGOTO_ERROR(H5E_DATATYPE, H5E_CANTINIT, H5I_INVALID_HID, "unable to retrieve member type");
+
+    /* Get an ID for the datatype */
+    if ((ret_value = H5I_register(H5I_DATATYPE, memb_dt, true)) < 0)
+        HGOTO_ERROR(H5E_DATATYPE, H5E_CANTREGISTER, H5I_INVALID_HID, "unable register datatype ID");
 
 done:
-    if(ret_value < 0)
-        if(memb_dt && H5T_close(memb_dt) < 0)
-            HDONE_ERROR(H5E_DATATYPE, H5E_CANTCLOSEOBJ, FAIL, "can't close datatype")
+    if (ret_value < 0)
+        if (memb_dt && H5T_close(memb_dt) < 0)
+            HDONE_ERROR(H5E_DATATYPE, H5E_CANTCLOSEOBJ, H5I_INVALID_HID, "can't close datatype");
 
     FUNC_LEAVE_API(ret_value)
 } /* end H5Tget_member_type() */
 
-
 /*-------------------------------------------------------------------------
  * Function:	H5T_get_member_type
  *
- * Purpose:	Private function for H5Tget_member_type.  Returns the data
- *              type of the specified member.
+ * Purpose:     Returns a copy of the data type of the specified member.
  *
  * Return:	Success:	A copy of the member datatype;
  *				modifying the returned datatype does not
@@ -273,56 +222,81 @@ done:
  *
  *		Failure:        NULL
  *
- * Programmer:	Raymond Lu
- *	        October 8, 2002
- *
  *-------------------------------------------------------------------------
  */
 H5T_t *
-H5T_get_member_type(const H5T_t *dt, unsigned membno, H5T_copy_t method)
+H5T_get_member_type(const H5T_t *dt, unsigned membno)
 {
-    H5T_t	*ret_value;     /* Return value */
+    H5T_t *ret_value = NULL; /* Return value */
 
     FUNC_ENTER_NOAPI(NULL)
 
-    HDassert(dt);
-    HDassert(membno < dt->shared->u.compnd.nmembs);
+    /* Sanity checks */
+    assert(dt);
+    assert(membno < dt->shared->u.compnd.nmembs);
 
-    /* Copy datatype into an atom */
-    if(NULL == (ret_value = H5T_copy(dt->shared->u.compnd.memb[membno].type, method)))
-	HGOTO_ERROR(H5E_DATATYPE, H5E_CANTINIT, NULL, "unable to copy member datatype")
+    /* Copy datatype */
+    if (NULL == (ret_value = H5T_copy(dt->shared->u.compnd.memb[membno].type, H5T_COPY_TRANSIENT)))
+        HGOTO_ERROR(H5E_DATATYPE, H5E_CANTCOPY, NULL, "unable to copy member datatype");
 
 done:
     FUNC_LEAVE_NOAPI(ret_value)
 } /* end H5T_get_member_type() */
 
-
 /*-------------------------------------------------------------------------
- * Function:	H5T_get_member_size
+ * Function:	H5T__reopen_member_type
+ *
+ * Purpose:	Private function for H5Tget_member_type.  Returns a re-opened
+ *              copy of the data type of the specified member.
+ *
+ * Return:	Success:	A copy of the member datatype;
+ *				modifying the returned datatype does not
+ *				modify the member type.
+ *
+ *		Failure:        NULL
+ *
+ *-------------------------------------------------------------------------
+ */
+static H5T_t *
+H5T__reopen_member_type(const H5T_t *dt, unsigned membno)
+{
+    H5T_t *ret_value = NULL; /* Return value */
+
+    FUNC_ENTER_PACKAGE
+
+    /* Sanity checks */
+    assert(dt);
+    assert(membno < dt->shared->u.compnd.nmembs);
+
+    /* Copy datatype, possibly re-opening it */
+    if (NULL == (ret_value = H5T_copy_reopen(dt->shared->u.compnd.memb[membno].type)))
+        HGOTO_ERROR(H5E_DATATYPE, H5E_CANTCOPY, NULL, "unable to reopen member datatype");
+
+done:
+    FUNC_LEAVE_NOAPI(ret_value)
+} /* end H5T__reopen_member_type() */
+
+/*-------------------------------------------------------------------------
+ * Function:	H5T__get_member_size
  *
  * Purpose:	Returns the size of the specified member.
  *
  * Return:	Success:	The size in bytes of the member's datatype.
  *		Failure:        0
  *
- * Programmer:	Quincey Koziol
- *	        October 4, 2004
- *
  *-------------------------------------------------------------------------
  */
 size_t
-H5T_get_member_size(const H5T_t *dt, unsigned membno)
+H5T__get_member_size(const H5T_t *dt, unsigned membno)
 {
-    FUNC_ENTER_NOAPI_NOINIT_NOERR
-
-    HDassert(dt);
-    HDassert(membno < dt->shared->u.compnd.nmembs);
+    FUNC_ENTER_PACKAGE_NOERR
 
+    assert(dt);
+    assert(membno < dt->shared->u.compnd.nmembs);
 
     FUNC_LEAVE_NOAPI(dt->shared->u.compnd.memb[membno].type->shared->size)
-} /* end H5T_get_member_size() */
+} /* end H5T__get_member_size() */
 
-
 /*-------------------------------------------------------------------------
  * Function:	H5Tinsert
  *
@@ -340,44 +314,39 @@ H5T_get_member_size(const H5T_t *dt, unsigned membno)
  *
  * Errors:
  *
- * Programmer:	Robb Matzke
- *		Monday, December  8, 1997
- *
- * Modifications:
- *
  *-------------------------------------------------------------------------
  */
 herr_t
 H5Tinsert(hid_t parent_id, const char *name, size_t offset, hid_t member_id)
 {
-    H5T_t	*parent;		/* The compound parent datatype */
-    H5T_t	*member;		/* The member datatype	*/
-    herr_t      ret_value = SUCCEED;    /* Return value */
+    H5T_t *parent;              /* The compound parent datatype */
+    H5T_t *member;              /* The member datatype	*/
+    herr_t ret_value = SUCCEED; /* Return value */
 
     FUNC_ENTER_API(FAIL)
     H5TRACE4("e", "i*szi", parent_id, name, offset, member_id);
 
     /* Check args */
-    if(parent_id == member_id)
-	HGOTO_ERROR(H5E_ARGS, H5E_BADVALUE, FAIL, "can't insert compound datatype within itself")
-    if(NULL == (parent = (H5T_t *)H5I_object_verify(parent_id, H5I_DATATYPE)) || H5T_COMPOUND != parent->shared->type)
-	HGOTO_ERROR(H5E_ARGS, H5E_BADTYPE, FAIL, "not a compound datatype")
-    if(H5T_STATE_TRANSIENT != parent->shared->state)
-	HGOTO_ERROR(H5E_ARGS, H5E_BADVALUE, FAIL, "parent type read-only")
-    if(!name || !*name)
-	HGOTO_ERROR(H5E_ARGS, H5E_BADVALUE, FAIL, "no member name")
-    if(NULL == (member = (H5T_t *)H5I_object_verify(member_id, H5I_DATATYPE)))
-	HGOTO_ERROR(H5E_ARGS, H5E_BADTYPE, FAIL, "not a datatype")
+    if (parent_id == member_id)
+        HGOTO_ERROR(H5E_ARGS, H5E_BADVALUE, FAIL, "can't insert compound datatype within itself");
+    if (NULL == (parent = (H5T_t *)H5I_object_verify(parent_id, H5I_DATATYPE)) ||
+        H5T_COMPOUND != parent->shared->type)
+        HGOTO_ERROR(H5E_ARGS, H5E_BADTYPE, FAIL, "not a compound datatype");
+    if (H5T_STATE_TRANSIENT != parent->shared->state)
+        HGOTO_ERROR(H5E_ARGS, H5E_BADVALUE, FAIL, "parent type read-only");
+    if (!name || !*name)
+        HGOTO_ERROR(H5E_ARGS, H5E_BADVALUE, FAIL, "no member name");
+    if (NULL == (member = (H5T_t *)H5I_object_verify(member_id, H5I_DATATYPE)))
+        HGOTO_ERROR(H5E_ARGS, H5E_BADTYPE, FAIL, "not a datatype");
 
     /* Insert */
-    if(H5T_insert(parent, name, offset, member) < 0)
-        HGOTO_ERROR(H5E_DATATYPE, H5E_CANTINSERT, FAIL, "unable to insert member")
+    if (H5T__insert(parent, name, offset, member) < 0)
+        HGOTO_ERROR(H5E_DATATYPE, H5E_CANTINSERT, FAIL, "unable to insert member");
 
 done:
     FUNC_LEAVE_API(ret_value)
 } /* end H5Tinsert() */
 
-
 /*-------------------------------------------------------------------------
  * Function:	H5Tpack
  *
@@ -386,37 +355,32 @@ done:
  *
  * Return:	Non-negative on success/Negative on failure
  *
- * Programmer:	Robb Matzke
- *		Wednesday, January  7, 1998
- *
- * Modifications:
- *
  *-------------------------------------------------------------------------
  */
 herr_t
 H5Tpack(hid_t type_id)
 {
-    H5T_t	*dt;                    /* Datatype to modify */
-    herr_t      ret_value = SUCCEED;    /* Return value */
+    H5T_t *dt;                  /* Datatype to modify */
+    herr_t ret_value = SUCCEED; /* Return value */
 
     FUNC_ENTER_API(FAIL)
     H5TRACE1("e", "i", type_id);
 
     /* Check args */
-    if(NULL == (dt = (H5T_t *)H5I_object_verify(type_id, H5I_DATATYPE)) || H5T_detect_class(dt, H5T_COMPOUND, TRUE) <= 0)
-	HGOTO_ERROR(H5E_ARGS, H5E_BADTYPE, FAIL, "not a compound datatype")
+    if (NULL == (dt = (H5T_t *)H5I_object_verify(type_id, H5I_DATATYPE)) ||
+        H5T_detect_class(dt, H5T_COMPOUND, true) <= 0)
+        HGOTO_ERROR(H5E_ARGS, H5E_BADTYPE, FAIL, "not a compound datatype");
 
     /* Pack */
-    if(H5T_pack(dt) < 0)
-	HGOTO_ERROR(H5E_DATATYPE, H5E_CANTINIT, FAIL, "unable to pack compound datatype")
+    if (H5T__pack(dt) < 0)
+        HGOTO_ERROR(H5E_DATATYPE, H5E_CANTINIT, FAIL, "unable to pack compound datatype");
 
 done:
     FUNC_LEAVE_API(ret_value)
 } /* end H5Tpack() */
 
-
 /*-------------------------------------------------------------------------
- * Function:	H5T_insert
+ * Function:	H5T__insert
  *
  * Purpose:	Adds a new MEMBER to the compound datatype PARENT.  The new
  *		member will have a NAME that is unique within PARENT and an
@@ -425,151 +389,146 @@ done:
  *
  * Return:	Non-negative on success/Negative on failure
  *
- * Programmer:	Robb Matzke
- *		Monday, December  8, 1997
- *
  *-------------------------------------------------------------------------
  */
 herr_t
-H5T_insert(H5T_t *parent, const char *name, size_t offset, const H5T_t *member)
+H5T__insert(H5T_t *parent, const char *name, size_t offset, const H5T_t *member)
 {
-    unsigned	idx;                        /* Index of member to insert */
-    size_t	total_size;
-    unsigned	i;                          /* Local index variable */
-    herr_t      ret_value = SUCCEED;        /* Return value */
+    unsigned idx; /* Index of member to insert */
+    size_t   total_size;
+    unsigned i;                   /* Local index variable */
+    herr_t   ret_value = SUCCEED; /* Return value */
 
-    FUNC_ENTER_NOAPI(FAIL)
+    FUNC_ENTER_PACKAGE
 
     /* check args */
-    HDassert(parent && H5T_COMPOUND == parent->shared->type);
-    HDassert(H5T_STATE_TRANSIENT == parent->shared->state);
-    HDassert(member);
-    HDassert(name && *name);
+    assert(parent && H5T_COMPOUND == parent->shared->type);
+    assert(H5T_STATE_TRANSIENT == parent->shared->state);
+    assert(member);
+    assert(name && *name);
 
     /* Does NAME already exist in PARENT? */
-    for(i = 0; i < parent->shared->u.compnd.nmembs; i++)
-	if(!HDstrcmp(parent->shared->u.compnd.memb[i].name, name))
-	    HGOTO_ERROR(H5E_DATATYPE, H5E_CANTINSERT, FAIL, "member name is not unique")
+    for (i = 0; i < parent->shared->u.compnd.nmembs; i++)
+        if (!strcmp(parent->shared->u.compnd.memb[i].name, name))
+            HGOTO_ERROR(H5E_DATATYPE, H5E_CANTINSERT, FAIL, "member name is not unique");
 
     /* Does the new member overlap any existing member ? */
     total_size = member->shared->size;
-    for(i = 0; i < parent->shared->u.compnd.nmembs; i++)
-        if((offset <= parent->shared->u.compnd.memb[i].offset &&
-                 (offset + total_size) > parent->shared->u.compnd.memb[i].offset) ||
-                (parent->shared->u.compnd.memb[i].offset <= offset &&
-                 (parent->shared->u.compnd.memb[i].offset +
-                 parent->shared->u.compnd.memb[i].size) > offset))
-            HGOTO_ERROR(H5E_DATATYPE, H5E_CANTINSERT, FAIL, "member overlaps with another member")
+    for (i = 0; i < parent->shared->u.compnd.nmembs; i++)
+        if ((offset <= parent->shared->u.compnd.memb[i].offset &&
+             (offset + total_size) > parent->shared->u.compnd.memb[i].offset) ||
+            (parent->shared->u.compnd.memb[i].offset <= offset &&
+             (parent->shared->u.compnd.memb[i].offset + parent->shared->u.compnd.memb[i].size) > offset))
+            HGOTO_ERROR(H5E_DATATYPE, H5E_CANTINSERT, FAIL, "member overlaps with another member");
 
     /* Does the new member overlap the end of the compound type? */
-    if((offset + total_size) > parent->shared->size)
-        HGOTO_ERROR(H5E_DATATYPE, H5E_CANTINSERT, FAIL, "member extends past end of compound type")
+    if ((offset + total_size) > parent->shared->size)
+        HGOTO_ERROR(H5E_DATATYPE, H5E_CANTINSERT, FAIL, "member extends past end of compound type");
 
     /* Increase member array if necessary */
-    if(parent->shared->u.compnd.nmembs >= parent->shared->u.compnd.nalloc) {
-        unsigned na = MAX(1, parent->shared->u.compnd.nalloc * 2);
+    if (parent->shared->u.compnd.nmembs >= parent->shared->u.compnd.nalloc) {
+        unsigned     na = MAX(1, parent->shared->u.compnd.nalloc * 2);
         H5T_cmemb_t *x = (H5T_cmemb_t *)H5MM_realloc(parent->shared->u.compnd.memb, na * sizeof(H5T_cmemb_t));
 
-        if(!x)
-            HGOTO_ERROR(H5E_DATATYPE, H5E_CANTALLOC, FAIL, "memory allocation failed")
+        if (!x)
+            HGOTO_ERROR(H5E_DATATYPE, H5E_CANTALLOC, FAIL, "memory allocation failed");
         parent->shared->u.compnd.nalloc = na;
-        parent->shared->u.compnd.memb = x;
+        parent->shared->u.compnd.memb   = x;
     } /* end if */
 
     /* Add member to end of member array */
-    idx = parent->shared->u.compnd.nmembs;
-    parent->shared->u.compnd.memb[idx].name = H5MM_xstrdup(name);
+    idx                                       = parent->shared->u.compnd.nmembs;
     parent->shared->u.compnd.memb[idx].offset = offset;
-    parent->shared->u.compnd.memb[idx].size = total_size;
-    parent->shared->u.compnd.memb[idx].type = H5T_copy(member, H5T_COPY_ALL);
+    parent->shared->u.compnd.memb[idx].size   = total_size;
+    if (NULL == (parent->shared->u.compnd.memb[idx].name = H5MM_xstrdup(name)))
+        HGOTO_ERROR(H5E_DATATYPE, H5E_CANTALLOC, FAIL, "couldn't duplicate name string");
+    if (NULL == (parent->shared->u.compnd.memb[idx].type = H5T_copy(member, H5T_COPY_ALL)))
+        HGOTO_ERROR(H5E_DATATYPE, H5E_CANTCOPY, FAIL, "couldn't copy datatype");
 
     parent->shared->u.compnd.sorted = H5T_SORT_NONE;
     parent->shared->u.compnd.nmembs++;
-    parent->shared->u.compnd.memb_size+=total_size;
+    parent->shared->u.compnd.memb_size += total_size;
 
     /* It should not be possible to get this far if the type is already packed
      * - the new member would overlap something */
-    HDassert(!(parent->shared->u.compnd.packed));
+    assert(!(parent->shared->u.compnd.packed));
 
     /* Determine if the compound datatype becomes packed */
-    H5T_update_packed(parent);
+    H5T__update_packed(parent);
 
     /* Set the "force conversion" flag if the field's datatype indicates */
-    if(member->shared->force_conv == TRUE)
-        parent->shared->force_conv = TRUE;
+    if (member->shared->force_conv == true)
+        parent->shared->force_conv = true;
 
     /* Check for member having a later version than the parent */
-    if(parent->shared->version < member->shared->version)
+    if (parent->shared->version < member->shared->version)
         /* Upgrade parent datatype (and all other members also) */
         /* (can't use a partial datatype and later versions of the format are
          *  more efficient, so might as well upgrade all members also... -QAK)
          */
-        if(H5T_upgrade_version(parent, member->shared->version) < 0)
-	    HGOTO_ERROR(H5E_DATATYPE, H5E_CANTSET, FAIL, "can't upgrade member encoding version")
+        if (H5T__upgrade_version(parent, member->shared->version) < 0)
+            HGOTO_ERROR(H5E_DATATYPE, H5E_CANTSET, FAIL, "can't upgrade member encoding version");
 
 done:
     FUNC_LEAVE_NOAPI(ret_value)
-} /* end H5T_insert() */
+} /* end H5T__insert() */
 
-
 /*-------------------------------------------------------------------------
- * Function:	H5T_pack
+ * Function:	H5T__pack
  *
  * Purpose:	Recursively packs a compound datatype by removing padding
  *		bytes. This is done in place (that is, destructively).
  *
  * Return:	Non-negative on success/Negative on failure
  *
- * Programmer:	Robb Matzke
- *		Wednesday, January  7, 1998
- *
  *-------------------------------------------------------------------------
  */
 static herr_t
-H5T_pack(const H5T_t *dt)
+H5T__pack(const H5T_t *dt)
 {
-    herr_t      ret_value = SUCCEED;    /* Return value */
+    herr_t ret_value = SUCCEED; /* Return value */
 
-    FUNC_ENTER_NOAPI_NOINIT
+    FUNC_ENTER_PACKAGE
 
-    HDassert(dt);
+    assert(dt);
 
-    if(H5T_detect_class(dt, H5T_COMPOUND, FALSE) > 0) {
+    if (H5T_detect_class(dt, H5T_COMPOUND, false) > 0) {
         /* If datatype has been packed, skip packing it and indicate success */
-        if(TRUE == H5T_is_packed(dt))
-            HGOTO_DONE(SUCCEED)
+        if (true == H5T__is_packed(dt))
+            HGOTO_DONE(SUCCEED);
 
         /* Check for packing unmodifiable datatype */
-        if(H5T_STATE_TRANSIENT != dt->shared->state)
-            HGOTO_ERROR(H5E_ARGS, H5E_BADVALUE, FAIL, "datatype is read-only")
+        if (H5T_STATE_TRANSIENT != dt->shared->state)
+            HGOTO_ERROR(H5E_ARGS, H5E_BADVALUE, FAIL, "datatype is read-only");
 
-        if(dt->shared->parent) {
-            if (H5T_pack(dt->shared->parent) < 0)
-                HGOTO_ERROR(H5E_DATATYPE, H5E_CANTINIT, FAIL, "unable to pack parent of datatype")
+        if (dt->shared->parent) {
+            if (H5T__pack(dt->shared->parent) < 0)
+                HGOTO_ERROR(H5E_DATATYPE, H5E_CANTINIT, FAIL, "unable to pack parent of datatype");
 
             /* Adjust size of datatype appropriately */
-            if(dt->shared->type == H5T_ARRAY)
+            if (dt->shared->type == H5T_ARRAY)
                 dt->shared->size = dt->shared->parent->shared->size * dt->shared->u.array.nelem;
-            else if(dt->shared->type != H5T_VLEN)
+            else if (dt->shared->type != H5T_VLEN)
                 dt->shared->size = dt->shared->parent->shared->size;
         } /* end if */
-        else if(dt->shared->type == H5T_COMPOUND) {
-            size_t	offset;                 /* Offset of member */
-            unsigned i;                     /* Local index variable */
+        else if (dt->shared->type == H5T_COMPOUND) {
+            size_t   offset; /* Offset of member */
+            unsigned i;      /* Local index variable */
 
             /* Recursively pack the members */
-            for(i = 0; i < dt->shared->u.compnd.nmembs; i++) {
-                if(H5T_pack(dt->shared->u.compnd.memb[i].type) < 0)
-                    HGOTO_ERROR(H5E_DATATYPE, H5E_CANTINIT, FAIL, "unable to pack part of a compound datatype")
+            for (i = 0; i < dt->shared->u.compnd.nmembs; i++) {
+                if (H5T__pack(dt->shared->u.compnd.memb[i].type) < 0)
+                    HGOTO_ERROR(H5E_DATATYPE, H5E_CANTINIT, FAIL,
+                                "unable to pack part of a compound datatype");
 
                 /* Update the member size */
                 dt->shared->u.compnd.memb[i].size = (dt->shared->u.compnd.memb[i].type)->shared->size;
             } /* end for */
 
             /* Remove padding between members */
-            if(H5T_sort_value(dt, NULL) < 0)
-		HGOTO_ERROR(H5E_INTERNAL, H5E_CANTCOMPARE, FAIL, "value sort failed")
-            for(i = 0, offset = 0; i < dt->shared->u.compnd.nmembs; i++) {
+            if (H5T__sort_value(dt, NULL) < 0)
+                HGOTO_ERROR(H5E_INTERNAL, H5E_CANTCOMPARE, FAIL, "value sort failed");
+            for (i = 0, offset = 0; i < dt->shared->u.compnd.nmembs; i++) {
                 dt->shared->u.compnd.memb[i].offset = offset;
                 offset += dt->shared->u.compnd.memb[i].size;
             }
@@ -578,54 +537,46 @@ H5T_pack(const H5T_t *dt)
             dt->shared->size = MAX(1, offset);
 
             /* Mark the type as packed now */
-            dt->shared->u.compnd.packed = TRUE;
+            dt->shared->u.compnd.packed = true;
         } /* end if */
-    } /* end if */
+    }     /* end if */
 
 done:
     FUNC_LEAVE_NOAPI(ret_value)
-} /* end H5T_pack() */
+} /* end H5T__pack() */
 
-
 /*-------------------------------------------------------------------------
- * Function:	H5T_is_packed
+ * Function:	H5T__is_packed
  *
  * Purpose:	Checks whether a datatype which is compound (or has compound
  *              components) is packed.
  *
  * Return:	Non-negative on success/Negative on failure
  *
- * Programmer:	Quincey Koziol
- *		Thursday, September 11, 2003
- *
- * Modifications:
- *
  *-------------------------------------------------------------------------
  */
-htri_t
-H5T_is_packed(const H5T_t *dt)
+static htri_t
+H5T__is_packed(const H5T_t *dt)
 {
-    htri_t      ret_value = TRUE;       /* Return value */
+    htri_t ret_value = true; /* Return value */
 
-    FUNC_ENTER_NOAPI_NOINIT_NOERR
+    FUNC_ENTER_PACKAGE_NOERR
 
-    HDassert(dt);
+    assert(dt);
 
     /* Go up the chain as far as possible */
-    while(dt->shared->parent)
+    while (dt->shared->parent)
         dt = dt->shared->parent;
 
     /* If this is a compound datatype, check if it is packed */
-    if(dt->shared->type == H5T_COMPOUND) {
+    if (dt->shared->type == H5T_COMPOUND)
         ret_value = (htri_t)(dt->shared->u.compnd.packed);
-    } /* end if */
 
     FUNC_LEAVE_NOAPI(ret_value)
-} /* end H5T_is_packed() */
+} /* end H5T__is_packed() */
 
-
 /*-------------------------------------------------------------------------
- * Function:	H5T_update_packed
+ * Function:	H5T__update_packed
  *
  * Purpose:	Checks whether a datatype which is compound became packed
  *              after recent changes.  This function does not assume that
@@ -634,38 +585,32 @@ H5T_is_packed(const H5T_t *dt)
  *
  * Return:	void
  *
- * Programmer:	Neil Fortner
- *		Monday, October 19, 2009
- *
- * Modifications:
- *
  *-------------------------------------------------------------------------
  */
 void
-H5T_update_packed(const H5T_t *dt)
+H5T__update_packed(const H5T_t *dt)
 {
-    unsigned    i;                      /* Index */
+    unsigned i; /* Index */
 
-    FUNC_ENTER_NOAPI_NOINIT_NOERR
+    FUNC_ENTER_PACKAGE_NOERR
 
-    HDassert(dt);
-    HDassert(dt->shared->type == H5T_COMPOUND);
+    assert(dt);
+    assert(dt->shared->type == H5T_COMPOUND);
 
     /* First check if all space is used in the "top level" type */
-    if(dt->shared->size == dt->shared->u.compnd.memb_size) {
-        /* Set the packed flag to TRUE */
-        dt->shared->u.compnd.packed = TRUE;
+    if (dt->shared->size == dt->shared->u.compnd.memb_size) {
+        /* Set the packed flag to true */
+        dt->shared->u.compnd.packed = true;
 
         /* Now check if all members are packed */
-        for(i = 0; i < dt->shared->u.compnd.nmembs; i++)
-            if(!H5T_is_packed(dt->shared->u.compnd.memb[i].type)) {
-                dt->shared->u.compnd.packed = FALSE;
+        for (i = 0; i < dt->shared->u.compnd.nmembs; i++)
+            if (!H5T__is_packed(dt->shared->u.compnd.memb[i].type)) {
+                dt->shared->u.compnd.packed = false;
                 break;
             } /* end if */
-    } /* end if */
+    }         /* end if */
     else
-        dt->shared->u.compnd.packed = FALSE;
+        dt->shared->u.compnd.packed = false;
 
     FUNC_LEAVE_NOAPI_VOID
-} /* end H5T_update_packed() */
-
+} /* end H5T__update_packed() */
